@@ -3,7 +3,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2025	PgPool Global Development Group
+ * Copyright (c) 2003-2026	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -1927,6 +1927,8 @@ do_SCRAM(POOL_CONNECTION *frontend, POOL_CONNECTION *backend, int protoMajor, in
 				 * The request contains the name (as assigned by IANA) of the
 				 * authentication mechanism.
 				 */
+				if (sasl_state)
+					pg_fe_scram_free(sasl_state);
 				sasl_state = pg_SASL_init(backend, payload, payload_len, username, storedPassword);
 				if (!sasl_state)
 				{
@@ -2170,9 +2172,28 @@ ProcessNegotiateProtocol(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 			p = pool_read2(CONNECTION(cp, i), len);
 			if (!forwardMsg)
 			{
+				int32	num_unsupported;
+				StringInfoData	buf;
 				pool_write_and_flush(frontend, p, len); /* forward rest of
 														 * message */
 				forwardMsg = true;
+
+				/* debug out unsuported messages */
+				memcpy(&num_unsupported, p, sizeof(int32));
+				num_unsupported = ntohl(num_unsupported);
+				p += sizeof(int32);
+				if (num_unsupported > 0)
+				{
+					initStringInfo(&buf);
+					for (int i = 0; i < num_unsupported; i++)
+					{
+						appendStringInfoString(&buf, p);
+						appendStringInfoChar(&buf, ' ');
+						p += strlen(p) + 1;
+					}
+					elog(DEBUG1, "unsupported options: %s", buf.data);
+					pfree(buf.data);
+				}
 			}
 			/* save negatiate protocol version */
 			sp = CONNECTION_SLOT(cp, i);
