@@ -29,7 +29,8 @@
 
 #define POOL_PASSWD_FILENAME "pool_passwd"
 #define POOL_PASSWD_LEN 35
-#define MAX_POOL_PASSWD_LEN 132 /* In case of TEXT prefix(4byte) and plain text password(128byte)*/
+#define MAX_POOL_PASSWD_LEN 132 /* In case of TEXT prefix(4byte) and plain
+								 * text password(128byte) */
 
 #define MAX_USER_NAME_LEN	128
 #define MAX_PGPASS_LEN		128
@@ -47,7 +48,7 @@ typedef enum
 								 * pgpool-II child main process */
 	POOL_PASSWD_RW,				/* open pool_passwd in read/write mode. used
 								 * by pg_md5 command */
-}			POOL_PASSWD_MODE;
+} POOL_PASSWD_MODE;
 
 typedef enum PasswordType
 {
@@ -64,16 +65,16 @@ typedef struct UserPassword
 	char	   *userName;
 	char	   *password;
 	PasswordType passwordType;
-}			UserPassword;
+} UserPassword;
 
 typedef struct PasswordMapping
 {
 	UserPassword pgpoolUser;
 	UserPassword backendUser;
 	bool		mappedUser;
-}			PasswordMapping;
+} PasswordMapping;
 
-extern PasswordMapping * pool_get_user_credentials(char *username);
+extern PasswordMapping *pool_get_user_credentials(char *username);
 extern PasswordType get_password_type(const char *shadow_pass);
 extern void pool_init_pool_passwd(char *pool_passwd_filename, POOL_PASSWD_MODE mode);
 extern int	pool_create_passwdent(char *username, char *passwd);
@@ -84,6 +85,6 @@ extern void pool_reopen_passwd_file(void);
 extern char *get_decrypted_password(const char *shadow_pass);
 extern char *read_pool_key(char *key_file_path);
 extern char *get_pgpool_config_user_password(char *username, char *password_in_config);
-extern void delete_passwordMapping(PasswordMapping * pwdMapping);
-extern int check_password_type_is_not_md5(char *username, char *password_in_config);
+extern void delete_passwordMapping(PasswordMapping *pwdMapping);
+extern int	check_password_type_is_not_md5(char *username, char *password_in_config);
 #endif							/* POOL_PASSWD_H */
