@@ -20,38 +20,39 @@
  *
  * Global variables. Should be eventually removed.
  */
-#include <unistd.h> /*For getpid*/
+#include <unistd.h>				/* For getpid */
 #include "pool.h"
 #include "utils/elog.h"
 
 
 pid_t		mypid;				/* pgpool parent process id */
-pid_t		myProcPid;		/* process pid */
+pid_t		myProcPid;			/* process pid */
 ProcessType processType;
 ProcessState processState;
-bool		reset_query_error;	/* true if error returned from backend while processing reset queries */
+bool		reset_query_error;	/* true if error returned from backend while
+								 * processing reset queries */
 
 /*
  * Application name
  */
-static	char	*process_application_name = "main";
+static char *process_application_name = "main";
 
 /*
  * Fixed application names. ordered by ProcessType.
  */
-char	*application_names[] = {"main",
-								"child",
-								"sr_check_worker",
-								"heart_beat_sender",
-								"heart_beat_receiver",
-								"watchdog",
-								"life_check",
-								"follow_child",
-								"watchdog_utility",
-								"pcp_main",
-								"pcp_child",
-								"health_check",
-								"logger"
+char	   *application_names[] = {"main",
+	"child",
+	"sr_check_worker",
+	"heart_beat_sender",
+	"heart_beat_receiver",
+	"watchdog",
+	"life_check",
+	"follow_child",
+	"watchdog_utility",
+	"pcp_main",
+	"pcp_child",
+	"health_check",
+	"logger"
 };
 
 char *
@@ -90,7 +91,8 @@ set_application_name_with_string(char *string)
 void
 set_application_name_with_suffix(ProcessType ptype, int suffix)
 {
-	static char	appname_buf[POOLCONFIG_MAXNAMELEN +1];
+	static char appname_buf[POOLCONFIG_MAXNAMELEN + 1];
+
 	snprintf(appname_buf, POOLCONFIG_MAXNAMELEN, "%s%d", get_application_name_for_process(ptype), suffix);
 	set_application_name_with_string(appname_buf);
 }
@@ -104,7 +106,8 @@ get_application_name(void)
 	return process_application_name;
 }
 
-void SetProcessGlobalVariables(ProcessType pType)
+void
+SetProcessGlobalVariables(ProcessType pType)
 {
 	processType = pType;
 	myProcPid = getpid();
