@@ -3,7 +3,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2024	PgPool Global Development Group
+ * Copyright (c) 2003-2026	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -416,7 +416,7 @@ function_call_walker(Node *node, void *context)
 				if (function_volatile_property(fname, FUNC_VOLATILE))
 				{
 					ctx->has_function_call = true;
-					return false;
+					return true;
 				}
 				return raw_expression_tree_walker(node, function_call_walker, context);
 			}
@@ -441,7 +441,7 @@ function_call_walker(Node *node, void *context)
 				 * found a writing function.
 				 */
 				ctx->has_function_call = true;
-				return false;
+				return true;
 			}
 
 			/*
@@ -454,7 +454,7 @@ function_call_walker(Node *node, void *context)
 				{
 					/* Found. */
 					ctx->has_function_call = true;
-					return false;
+					return true;
 				}
 			}
 		}
@@ -483,7 +483,7 @@ system_catalog_walker(Node *node, void *context)
 		if (is_system_catalog(rgv->relname))
 		{
 			ctx->has_system_catalog = true;
-			return false;
+			return true;
 		}
 	}
 	return raw_expression_tree_walker(node, system_catalog_walker, context);
@@ -510,7 +510,7 @@ temp_table_walker(Node *node, void *context)
 		if (is_temp_table(rgv->relname))
 		{
 			ctx->has_temp_table = true;
-			return false;
+			return true;
 		}
 	}
 	return raw_expression_tree_walker(node, temp_table_walker, context);
@@ -540,7 +540,7 @@ unlogged_table_walker(Node *node, void *context)
 		if (is_unlogged_table(relname))
 		{
 			ctx->has_unlogged_table = true;
-			return false;
+			return true;
 		}
 	}
 	return raw_expression_tree_walker(node, unlogged_table_walker, context);
@@ -570,7 +570,7 @@ view_walker(Node *node, void *context)
 		if (is_view(relname))
 		{
 			ctx->has_view = true;
-			return false;
+			return true;
 		}
 	}
 	return raw_expression_tree_walker(node, view_walker, context);
@@ -600,7 +600,7 @@ row_security_enabled_walker(Node *node, void *context)
 		if (row_security_enabled(relname))
 		{
 			ctx->row_security = true;
-			return false;
+			return true;
 		}
 	}
 	return raw_expression_tree_walker(node, row_security_enabled_walker, context);
